### Name: Rvelslant
### Title: Downhole Seismic Analysis In R
### Aliases: Rvelslant


### ** Examples

# Load table of Dave Boore's downhole seismic data:
data(tt.s) # S-wave arrivals

# Select hole code 293:
f <- tt.s$hole.code == 293
example <- tt.s[f, ]
data <- list(tt.slant = example$tt.slant,
             hoffset = example$hoffset[1],
             z = example$z,
             sig = example$sig,
             hole.code = 293)

# If Using the Windows GUI, it is best to uncheck the 'Buffered output'
# option in the Misc pull-down menu. This will allow you to see the
# outputs to the console as they occur rather than all at once at the
# end.

# The command to calculate the layered model is:
mod1 <- Rvelslant(data)

# The default is to use depth on the vertical axis. However, if you
# prefer depth to be displayed on the horizontal axis, use:

mod1 <- Rvelslant(data, depth = "h")

  #####################################################
  #    Notes:
  # You can select layer boundaries by clicking on the
  # travel-time or residual plots. You can remove a
  # boundary by left clicking on it in the velocity
  # profile plot.
  
  # Right-click anywhere once your have found a model
  # that you want to save.
  #  -> In WINDOWS must select 'stop' after right-click
  #  -> In MAC OS, can use ESC key instead if you don't
  #     have a second mouse button.
  
  # The layered model depth to bottom, thickness, and
  # velocity will be printed to the terminal.
  
  # The default is to calculate the refracted ray path
  # according to Snell's law and iteratively update
  # the velocity mode. To override this, and do the
  # inversion assuming the raypaths are straight lines
  # from source to receiver, use:

mod2 <- Rvelslant(data, snell = FALSE, ntick = 10, grid = TRUE)

# To use the auto picker:
mod3 <- Rvelslant(data, auto = TRUE)

# To manually enter layer interfaces:
mod4 <- Rvelslant(data, bot = c(6.2, 9.5, 14.5, 29.5,
                    47, 54.5, 74.5, 89.5)) 

# To view the profiles, type:

velprofile(mod1)
velprofile(mod2, col = "green")

# If you have more than one model and you want to compare the profiles:

velprofile(mod1, col = "black")
velprofile(mod2, add = TRUE, col = "red")
velprofile(mod3, add = TRUE, col = "blue")

# To view the fit of travel-times and the residuals:
par(mfrow = c(1, 2))
plotmod(mod1)
plotresid(mod1)

# To save the model to a file
writemod(mod1, prefix = "hc293")




